@@ -5,7 +5,7 @@ use strict;
 use Carp;
 use Git;
 
-use version; our $VERSION = qv('0.0.7'); # Work with dates
+use version; our $VERSION = qv('0.1.0'); # Work with a few files
 
 # Other recommended modules (uncomment to use):
 #  use IO::Prompt;
@@ -18,9 +18,15 @@ use version; our $VERSION = qv('0.0.7'); # Work with dates
 sub new {
   my $class = shift;
   my $dir = shift || croak "Need a repo directory";
+  my $files_arrayref = shift;
   my ($repo_name)  = ($dir =~ m{/([^/]+)/?$} );
   my $repo = Git->repository (Directory => $dir);
-  my @these_revs = $repo->command('rev-list', '--all');
+  my @these_revs;
+  if ( $files_arrayref ) {
+    @these_revs = $repo->command('rev-list', '--all', '--', join(" ", @$files_arrayref));
+  } else { 
+    @these_revs = $repo->command('rev-list', '--all');
+  }
   my @commit_info;
   for my $commit ( reverse @these_revs ) {
     my $commit_info = $repo->command('show', '--pretty=fuller', $commit);
@@ -90,6 +96,7 @@ the shape
 
     { author => $author,
       committer => $committer,
+      commit_date => $date,
       files => \@files }
 
 =head2 hashes
@@ -114,7 +121,9 @@ Depends on L<Git>, which should be available either from your git
 installation or from CPAN.
 
 
+=head2 SEE ALSO
 
+L<Git::Raw> has an object oriented interface to repositories, including a class L<Git::Raw::Commit> to access commits. 
 
 =head1 BUGS AND LIMITATIONS
 
